##  Configuration Page Overview
The table below lists the tabs on the integration configuration page.
Tabs on the ServiceNow Configuration Page Tab | Details | Additional Information
---|---|---
Credentials | Configure credentials, partial sync mode, and the integration status. | [Credential Configuration](https://help.sap.com/docs/leanix/ea/setup-in-sap-leanix?locale=en-US&state=PRODUCTION&version=CLOUD#loio275cbd707a4410148e4dabcbf8405203__credential_configuration)
Mappings |  Configure the following:
  * Aggregation and linkage of software records, allowing you to streamline the import process and enhance data quality.
  * Fact sheet mappings.
  * Relation mappings.

|
  * [Aggregation and Linkage of Software Records](https://help.sap.com/docs/leanix/ea/aggregation-and-linkage-of-software-records?locale=en-US&state=PRODUCTION&version=CLOUD "The aggregation and linkage feature allows you to import multiple software records from ServiceNow in an aggregated way while automatically linking consolidated fact sheets to the reference catalog.")
  * [Fact Sheet Mapping Between ServiceNow and SAP LeanIX](https://help.sap.com/docs/leanix/ea/fact-sheet-mapping-between-servicenow-and-sap-leanix?locale=en-US&state=PRODUCTION&version=CLOUD "Configure mappings between specific fields in SAP LeanIX fact sheets and ServiceNow tables.")
  * [Matching Rules](https://help.sap.com/docs/leanix/ea/matching-rules?locale=en-US&state=PRODUCTION&version=CLOUD "Set up rules for matching fact sheets between ServiceNow and SAP LeanIX during the initial synchronization.")
  * [Relation Mapping Between ServiceNow and SAP LeanIX](https://help.sap.com/docs/leanix/ea/relation-mapping-between-servicenow-and-sap-leanix?locale=en-US&state=PRODUCTION&version=CLOUD "Map relations between records in ServiceNow and fact sheets in SAP LeanIX.")
  * [Relations Between Applications and Hardware/Software Items](https://help.sap.com/docs/leanix/ea/relations-between-applications-and-hardware-software-items?locale=en-US&state=PRODUCTION&version=CLOUD "Configure how the ServiceNow integration detects relations between applications and hardware/software items.")


Advanced | Configuration in JSON format, allowing you to configure features such as advanced relation mapping, dot walking, and more. | [ServiceNow Integration: Advanced Configuration](https://help.sap.com/docs/leanix/ea/servicenow-advanced-configuration?locale=en-US&state=PRODUCTION&version=CLOUD "Configure advanced settings for the ServiceNow integration.")
Versions |  Configuration versions in JSON format.
  * To compare two versions, select them, then click Compare.
  * To restore a previous version, select the current version and a previous version, then click Restore Previous Version on the page that appears.

|
Aggregation Status | When the aggregation and linkage of software records is enabled, this tab displays detected software items and their statuses. | [Aggregation Status](https://help.sap.com/docs/leanix/ea/aggregation-and-linkage-of-software-records?locale=en-US&state=PRODUCTION&version=CLOUD#loio275880827a441014af66a89d4304acfa__section_lmn_q5f_2gc)


